@@ -1,7 +1,7 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2018-2020, 2022 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2018-2020, 2022-2023 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2018 Attila Molnar <attilamolnar@hush.com>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -92,8 +92,10 @@ class CoreExport ClientProtocol::TagSelection
 
 class CoreExport ClientProtocol::MessageSource
 {
+ protected:
 	User* sourceuser;
 	const std::string* sourcestr;
+	bool sourceowned:1;
 
  public:
 	/** Constructor, sets the source to be the full host of a user or sets it to be nothing.
@@ -102,10 +104,17 @@ class CoreExport ClientProtocol::MessageSource
 	 * Optional, defaults to NULL.
 	 */
 	MessageSource(User* Sourceuser = NULL)
+		: sourceowned(false)
 	{
 		SetSourceUser(Sourceuser);
 	}
 
+	~MessageSource()
+	{
+		if (sourceowned && sourcestr)
+			delete sourcestr;
+	}
+
 	/** Constructor, sets the source to the supplied string and optionally sets the source user.
 	 * @param Sourcestr String to use as message source for serialization purposes. Must remain valid
 	 * as long as this object is alive.
@@ -114,6 +123,7 @@ class CoreExport ClientProtocol::MessageSource
 	 * Useful when the source string is synthesized but it is still related to a User.
 	 */
 	MessageSource(const std::string& Sourcestr, User* Sourceuser = NULL)
+		: sourceowned(false)
 	{
 		SetSource(Sourcestr, Sourceuser);
 	}
@@ -451,6 +461,12 @@ class CoreExport ClientProtocol::Message : public ClientProtocol::MessageSource
 			if (!curr.IsOwned())
 				ReplaceParam(j, curr);
 		}
+
+		if (GetSource())
+		{
+			sourcestr = new std::string(*GetSource());
+			sourceowned = true;
+		}
 	}
 
 	void SetSideEffect(bool Sideeffect) { sideeffect = Sideeffect; }
