@@ -3,14 +3,14 @@
  *
  *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
  *   Copyright (C) 2018 Adam <Adam@anope.org>
- *   Copyright (C) 2017-2019, 2021 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2017-2019, 2021-2022 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013-2014, 2016 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2009 John Brooks <special@inspircd.org>
  *   Copyright (C) 2008 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2006-2008, 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2006-2008 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -116,9 +116,38 @@ class CommandWho : public SplitCommand
  private:
 	ChanModeReference secretmode;
 	ChanModeReference privatemode;
-	UserModeReference hidechansmode;
 	UserModeReference invisiblemode;
 	Events::ModuleEventProvider whoevprov;
+	Events::ModuleEventProvider whomatchevprov;
+	Events::ModuleEventProvider whovisibleevprov;
+
+	void BuildOpLevels()
+	{
+		// Build a map of prefixes ordered descending by their rank.
+		typedef std::multimap<unsigned int, const PrefixMode*, std::greater<unsigned int> > RankMap;
+		RankMap ranks;
+		const ModeParser::PrefixModeList& modes = ServerInstance->Modes.GetPrefixModes();
+		for (ModeParser::PrefixModeList::const_iterator iter = modes.begin(); iter != modes.end(); ++iter)
+		{
+			const PrefixMode* pm = *iter;
+			ranks.insert(std::make_pair(pm->GetPrefixRank(), pm));
+		}
+
+		// Now we have the ranks ordered we can assign them levels.
+		unsigned int lastrank = 0;
+		unsigned int oplevel = 0;
+		for (RankMap::const_iterator iter = ranks.begin(); iter != ranks.end(); ++iter)
+		{
+			const PrefixMode* pm = iter->second;
+			if (iter != ranks.begin() && pm->GetPrefixRank() != lastrank)
+				oplevel++; // Keep the same op level for modes with the same prefix rank.
+
+			lastrank = pm->GetPrefixRank();
+			oplevels[pm->GetModeChar()] = ConvToStr(oplevel);
+			ServerInstance->Logs->Log(MODNAME, LOG_DEBUG, "Assigned oplevel %u to the %c (%s) prefix mode.",
+				oplevel, pm->GetModeChar(), pm->name.c_str());
+		}
+	}
 
 	/** Determines whether a user can view the users of a channel. */
 	bool CanView(Channel* chan, User* user)
@@ -136,15 +165,26 @@ class CommandWho : public SplitCommand
 	}
 
 	/** Gets the first channel which is visible between the source and the target users. */
-	Membership* GetFirstVisibleChannel(LocalUser* source, User* user)
+	Membership* GetFirstVisibleChannel(const WhoData& data, LocalUser* source, User* user)
 	{
 		for (User::ChanList::iterator iter = user->chans.begin(); iter != user->chans.end(); ++iter)
 		{
 			Membership* memb = *iter;
 
-			// TODO: move the +I check into m_hidechans.
-			bool has_modes = memb->chan->IsModeSet(secretmode) || memb->chan->IsModeSet(privatemode) || user->IsModeSet(hidechansmode);
-			if (source == user || !has_modes || memb->chan->HasUser(source))
+			// Let a module handle this first if it wants to.
+			ModResult res;
+			FIRST_MOD_RESULT_CUSTOM(whovisibleevprov, Who::VisibleEventListener, OnWhoVisible, res, (data, source, memb));
+			if (res == MOD_RES_ALLOW)
+				return memb; // Module explicitly picked this chan.
+
+			if (res == MOD_RES_DENY)
+				continue; // Module explicitly rejected this chan.
+
+			// A module didn't specify either way so use the default behaviour:
+			// 1. The requesting user is getting a WHO response for themself.
+			// 2. The +s (secret) and +p (private) channel modes are not set.
+			// 3. The requesting user is a member of the channel.
+			if (source == user || (!memb->chan->IsModeSet(secretmode) && !memb->chan->IsModeSet(privatemode)) || memb->chan->HasUser(source))
 				return memb;
 		}
 		return NULL;
@@ -154,7 +194,7 @@ class CommandWho : public SplitCommand
 	bool MatchChannel(LocalUser* source, Membership* memb, WhoData& data);
 
 	/** Determines whether WHO flags match a specific user. */
-	static bool MatchUser(LocalUser* source, User* target, WhoData& data);
+	bool MatchUser(LocalUser* source, User* target, WhoData& data);
 
 	/** Performs a WHO request on a channel. */
 	void WhoChannel(LocalUser* source, const std::vector<std::string>& parameters, Channel* c, WhoData& data);
@@ -168,13 +208,16 @@ class CommandWho : public SplitCommand
 	void WhoUsers(LocalUser* source, const std::vector<std::string>& parameters, const T& users, WhoData& data);
 
  public:
+	insp::flat_map<char, std::string> oplevels;
+
 	CommandWho(Module* parent)
 		: SplitCommand(parent, "WHO", 1, 3)
 		, secretmode(parent, "secret")
 		, privatemode(parent, "private")
-		, hidechansmode(parent, "hidechans")
 		, invisiblemode(parent, "invisible")
 		, whoevprov(parent, "event/who")
+		, whomatchevprov(parent, "event/who-match")
+		, whovisibleevprov(parent, "event/who-visible")
 	{
 		allow_empty_last_param = false;
 		syntax = "<server>|<nick>|<channel>|<realname>|<host>|0 [[Aafhilmnoprstux][%acdfhilnorstu] <server>|<nick>|<channel>|<realname>|<host>|0]";
@@ -238,6 +281,15 @@ bool CommandWho::MatchUser(LocalUser* source, User* user, WhoData& data)
 	if (data.flags['l'] && source_can_see_server && !lu)
 		return false;
 
+	// Let a module handle this first if it wants to.
+	ModResult res;
+	FIRST_MOD_RESULT_CUSTOM(whomatchevprov, Who::MatchEventListener, OnWhoMatch, res, (data, source, user));
+	if (res == MOD_RES_ALLOW)
+		return true; // Module explicitly matched.
+
+	else if (res == MOD_RES_DENY)
+		return false; // Module explicitly rejected.
+
 	// The source wants to match against users' away messages.
 	bool match = false;
 	if (data.flags['A'])
@@ -412,7 +464,7 @@ void CommandWho::WhoUsers(LocalUser* source, const std::vector<std::string>& par
 void CommandWho::SendWhoLine(LocalUser* source, const std::vector<std::string>& parameters, Membership* memb, User* user, WhoData& data)
 {
 	if (!memb)
-		memb = GetFirstVisibleChannel(source, user);
+		memb = GetFirstVisibleChannel(data, source, user);
 
 	bool source_can_see_target = source == user || source->HasPrivPermission("users/auspex");
 	Numeric::Numeric wholine(data.whox ? RPL_WHOSPCRPL : RPL_WHOREPLY);
@@ -496,7 +548,14 @@ void CommandWho::SendWhoLine(LocalUser* source, const std::vector<std::string>&
 
 		// Include the user's operator rank level.
 		if (data.whox_fields['o'])
-			wholine.push(memb ? ConvToStr(memb->getRank()) : "0");
+		{
+			// If we haven't built a table to convert from InspIRCd member
+			// ranks to WHOX oplevels yet we need to do that here.
+			if (oplevels.empty())
+				BuildOpLevels();
+
+			wholine.push(memb && !memb->modes.empty() ? oplevels[memb->modes[0]] : "n/a");
+		}
 
 		// Include the user's real name.
 		if (data.whox_fields['r'])
@@ -560,9 +619,9 @@ CmdResult CommandWho::HandleLocal(LocalUser* user, const Params& parameters)
 	WhoData data(parameters);
 
 	// Is the source running a WHO on a channel?
-	Channel* chan = ServerInstance->FindChan(data.matchtext);
-	if (chan)
-		WhoChannel(user, parameters, chan, data);
+	data.matchchan = ServerInstance->FindChan(data.matchtext);
+	if (data.matchchan)
+		WhoChannel(user, parameters, data.matchchan, data);
 
 	// If we only want to match against opers we only have to iterate the oper list.
 	else if (data.flags['o'])
@@ -598,6 +657,18 @@ class CoreModWho : public Module
 		tokens["WHOX"];
 	}
 
+	void OnServiceAdd(ServiceProvider& provider) CXX11_OVERRIDE
+	{
+		// If the service is a prefix mode we need to rebuild the oplevel map.
+		if (provider.service == SERVICE_MODE && static_cast<ModeHandler&>(provider).IsPrefixMode())
+			cmd.oplevels.clear();
+	}
+
+	void OnServiceDel(ServiceProvider& provider) CXX11_OVERRIDE
+	{
+		this->OnServiceAdd(provider);
+	}
+
 	Version GetVersion() CXX11_OVERRIDE
 	{
 		return Version("Provides the WHO command", VF_VENDOR|VF_CORE);
