@@ -4,7 +4,7 @@
  *   Copyright (C) 2021 Val Lorentz <progval+git@progval.net>
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
  *   Copyright (C) 2018 Chris Novakovic
- *   Copyright (C) 2013, 2017-2022 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2017-2023 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013 Adam <Adam@anope.org>
  *   Copyright (C) 2012-2014, 2016, 2018 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012-2013 ChrisTX <xpipe@hotmail.de>
@@ -664,12 +664,13 @@ void InspIRCd::Run()
 
 		UpdateTime();
 
-		/* Run background module timers every few seconds
-		 * (the docs say modules should not rely on accurate
-		 * timing using this event, so we dont have to
-		 * time this exactly).
-		 */
+		// Normally we want to limit the mainloop to processing data
+		// once a second but this can cause problems with testing
+		// software like irctest. Don't define this unless you know
+		// what you are doing.
+#ifndef INSPIRCD_UNLIMITED_MAINLOOP
 		if (TIME.tv_sec != OLDTIME)
+#endif
 		{
 			CollectStats();
 			CheckTimeSkip(OLDTIME, TIME.tv_sec);
