@@ -4,7 +4,7 @@
  *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
  *   Copyright (C) 2015 Daniel Vassdal <shutter@canternet.org>
  *   Copyright (C) 2013-2014 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2013, 2016-2023 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2016-2024 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2012 ChrisTX <xpipe@hotmail.de>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
@@ -334,6 +334,12 @@ class SQLConnection : public SQL::Provider
 	// true upon success.
 	bool Connect()
 	{
+		if (connection)
+		{
+			mysql_close(connection);
+			connection = NULL;
+		}
+
 		connection = mysql_init(connection);
 
 		// Set the connection timeout.
