@@ -2,7 +2,7 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
- *   Copyright (C) 2016-2023 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2016-2024 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2016-2017 Attila Molnar <attilamolnar@hush.com>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -44,6 +44,11 @@
 # endif
 #endif
 
+// Work around mbedTLS using C99 features that are not part of C++.
+#ifdef __clang__
+# pragma clang diagnostic ignored "-Wc99-extensions"
+#endif
+
 #include <mbedtls/ctr_drbg.h>
 #include <mbedtls/dhm.h>
 #include <mbedtls/ecp.h>
