@@ -2,7 +2,7 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2019 Robby <robby@chatbelgie.be>
- *   Copyright (C) 2018-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2018-2021 Sadie Powell <sadie@witchery.services>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -157,19 +157,21 @@ class AntiCapsMode : public ParamMode<AntiCapsMode, SimpleExtItem<AntiCapsSettin
 class ModuleAntiCaps : public Module
 {
  private:
+	ChanModeReference banmode;
 	CheckExemption::EventProvider exemptionprov;
-	std::bitset<UCHAR_MAX> uppercase;
-	std::bitset<UCHAR_MAX> lowercase;
+	std::bitset<UCHAR_MAX + 1> uppercase;
+	std::bitset<UCHAR_MAX + 1> lowercase;
 	AntiCapsMode mode;
 
 	void CreateBan(Channel* channel, User* user, bool mute)
 	{
-		std::string banmask(mute ? "m:" : "");
-		banmask.append("*!*@");
+		std::string banmask(mute ? "m:*!" : "*!");
+		banmask.append(user->GetBanIdent());
+		banmask.append("@");
 		banmask.append(user->GetDisplayedHost());
 
 		Modes::ChangeList changelist;
-		changelist.push_add(ServerInstance->Modes->FindMode('b', MODETYPE_CHANNEL), banmask);
+		changelist.push_add(*banmode, banmask);
 		ServerInstance->Modes->Process(ServerInstance->FakeClient, channel, NULL, changelist);
 	}
 
@@ -180,7 +182,8 @@ class ModuleAntiCaps : public Module
 
  public:
 	ModuleAntiCaps()
-		: exemptionprov(this)
+		: banmode(this, "ban")
+		, exemptionprov(this)
 		, mode(this)
 	{
 	}
