@@ -1,7 +1,7 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2013, 2018, 2021-2022 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2018, 2022, 2024 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012-2013, 2015-2016 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
@@ -82,7 +82,7 @@ class ModuleHideChans CXX11_FINAL
 
 	ModResult OnWhoisLine(Whois::Context& whois, Numeric::Numeric& numeric) CXX11_OVERRIDE
 	{
-		if (numeric.GetNumeric() != RPL_WHOISCHANNELS)
+		if (numeric.GetNumeric() != RPL_WHOISCHANNELS && numeric.GetNumeric() != RPL_CHANNELSMSG)
 			return MOD_RES_PASSTHRU;
 
 		return ShouldHideChans(whois.GetSource(), whois.GetTarget());
