@@ -3,7 +3,7 @@
  *
  *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
  *   Copyright (C) 2019 Matt Schatz <genius3000@g3k.solutions>
- *   Copyright (C) 2013, 2017-2021 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2017-2021, 2023 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2012 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
@@ -108,7 +108,9 @@ class ModuleNoCTCP : public Module
 				User* u = target.Get<User>();
 				if (u->IsModeSet(ncu))
 				{
-					user->WriteNumeric(Numerics::CannotSendTo(u, "CTCPs", &ncu));
+					// Don't send an error message if we're blocking an automatic CTCP reply.
+					if (details.type == MSG_NOTICE)
+						user->WriteNumeric(Numerics::CannotSendTo(u, "CTCPs", &ncu));
 					return MOD_RES_DENY;
 				}
 				break;
