@@ -2,7 +2,7 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2019 Robby <robby@chatbelgie.be>
- *   Copyright (C) 2017-2018 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2017-2018, 2023 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2016 Attila Molnar <attilamolnar@hush.com>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -207,6 +207,8 @@ class ModuleWatch
 	void Online(User* user)
 	{
 		SendAlert(user, user->nick, RPL_LOGON, "arrived online", user->age);
+		if (!user->awaymsg.empty())
+			OnUserAway(user);
 	}
 
 	void Offline(User* user, const std::string& nick)
