@@ -4,12 +4,11 @@
  *   Copyright (C) 2021 Herman <GermanAizek@yandex.ru>
  *   Copyright (C) 2019 Matt Schatz <genius3000@g3k.solutions>
  *   Copyright (C) 2014 Justin Crawford <Justasic@Gmail.com>
- *   Copyright (C) 2013, 2015, 2018-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2015, 2018-2020, 2022 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012-2013 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2012, 2014 Adam <Adam@anope.org>
  *   Copyright (C) 2012 ChrisTX <xpipe@hotmail.de>
- *   Copyright (C) 2010 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2008 Robin Burchell <robin+git@viroteck.net>
  *
@@ -103,7 +102,7 @@ class ModuleXLineDB
 		 *     -- w00t
 		 */
 		ServerInstance->Logs->Log(MODNAME, LOG_DEBUG, "Opening temporary database");
-		std::string xlinenewdbpath = xlinedbpath + ".new";
+		const std::string xlinenewdbpath = xlinedbpath + ".new." + ConvToStr(ServerInstance->Time());
 		std::ofstream stream(xlinenewdbpath.c_str());
 		if (!stream.is_open())
 		{
